@@ -422,16 +422,12 @@ class Task:
                         config = model_config
 
                 image = self.options.docker_image
-                _, version_main_number = utils.parse_version_number(image)
+                _, version_main_number, image_name, tag = utils.parse_version_number(image)
                 if version_main_number > 0:
-                    p = image.find(":")
-                    tag = image[p + 1:]
-                    image = image[:p]
                     r = requests.get(os.path.join(self.options.url, "docker/schema"),
-                                     params={'image': image, 'tag': tag}, auth=self.auth)
+                                     params={'image': image_name, 'tag': tag}, auth=self.auth)
                     if r.status_code != 200:
-                        raise RuntimeError('cannot retrieve schema from docker image %s,'
-                                           ' tag %s: %s' % (image, tag))
+                        raise RuntimeError('cannot retrieve schema from docker image: %s' % image)
                     schema_res = r.json()
                     schema = json.loads(schema_res)
                     # validate config against JSON schema
