@@ -7,6 +7,7 @@ import re
 import sys
 import fnmatch
 import socket
+import semver
 import tempfile
 import time
 import requests
@@ -25,7 +26,7 @@ logger = logging.getLogger("snw trans")
 
 
 def check_command(command):
-    p = command.index("-o")
+    p = command.index("-o") if "-o" in command else -1
     if p == -1:
         return False
     return command[p+1].startswith("launcher:"+hostname+"()()")
@@ -54,6 +55,15 @@ def get_status(t):
     return msg
 
 
+def is_lower_docker_version(current_image, comparison_version):
+    _, version_main_number, image_name, tag = utils.parse_version_number(current_image)
+    current_docker_version = tag[1:] if tag.startswith('v') else tag
+    if semver.match(current_docker_version, "<"+comparison_version):
+        return True
+
+    return False
+
+
 def argparse_define():
     parser = argparse.ArgumentParser()
     parser.add_argument('-u', '--url',
@@ -65,6 +75,7 @@ def argparse_define():
     parser.add_argument('-m', '--model', help='model')
     parser.add_argument('-c', '--config', help="configuration file (for `set` only)")
     parser.add_argument('-e', '--entity_owner', help='entity owner')
+    parser.add_argument('-g', '--gpus', help="number of gpus", type=int)
     parser.add_argument('-i', '--docker_image',
                               default=os.getenv('LAUNCHER_IMAGE', None),
                               help='Docker image (can be prefixed by docker_registry:)')
@@ -216,14 +227,14 @@ def execute(args, auth):
         if args.entity_owner:
             args_launch += ["-e", args.entity_owner]
         args_launch += ["-P", str(args.priority)]
+        if args.gpus:
+            args_launch += ["-g", str(args.gpus)]
         if args.docker_image:
             args_launch += ["-i", args.docker_image, "--upgrade", "none"]
         args_launch += ["--novalidschema"]
         args_launch += ["--", "-m", args.model]
         if args.config:
             args_launch += ["-c", args.config]
-        else:
-            args_launch += ["-c", '{"postprocess":{"remove_placeholders":true}}']
         args_launch += ["--config_update_mode", "merge"]
         args_launch += ["trans", "-i", tmp_file]
         args_launch += ["-o", "launcher:"+output_path]
@@ -233,9 +244,15 @@ def execute(args, auth):
 
         try:
             task = Task(launch_args, auth)
-            res = task.execute_command()
-            status, serviceList = utils.get_services(url=args.url, user_auth=auth)
-            res = launcher.process_request(serviceList, launch_args.cmd, launch_args.subcmd,
+            task.execute_command()
+            # Add {"postprocess": {"remove_placeholders": true}} config to docker command
+            # if the version of the systran/pn9_tf image < 1.64.0 (Ticket #57654)
+            if not args.config and is_lower_docker_version(launch_args.docker_image, "1.64.0"):
+                docker_command = launch_args.docker_command
+                launch_args.docker_command = ["-c", '{"postprocess":{"remove_placeholders":true}}'] + docker_command
+
+            status, service_list = utils.get_services(url=args.url, user_auth=auth)
+            res = launcher.process_request(service_list, launch_args.cmd, launch_args.subcmd,
                                            True, launch_args, auth=auth)
             task_id = res.split("\t")[1]
             if trim_joiner is not None:
@@ -257,7 +274,7 @@ def execute(args, auth):
     manager = enlighten.get_manager()
     status_format = "{task}: {file}{fill}{stage} ({time})"
     list_tasks = []
-    for t in sorted(r.json(), key=lambda t: t["launched_time"]):
+    for t in sorted(r.json(), key=lambda t: t["launched_time"] if t["launched_time"] is not None else "0"):
         if t["task_id"].endswith("_trans"):
             list_tasks.append([t["task_id"], None])
 
